@@ -1,7 +1,7 @@
-transaction_categories_cih = {
+cih = {
     "ecom_inter": "PAIEMENT INTERNET INTERNATIONAL",
     "ecom_national": "PAIEMENT INTERNET NATIONAL",
-    "wire_in_cih": "VIREMENT RECU DE",
+    "wire_in_same_bank": "VIREMENT RECU DE",
     "wire_in_conf": "VIRT RECU",
     "wire_out": "VIREMENT EMIS EN FAVEUR DE",
     "withdrawal_gab": "RETRAIT CARTE",
@@ -12,3 +12,21 @@ transaction_categories_cih = {
     "ext_gab_fee": "FRAIS RETRAIT GAB CONFRERE",
     "allow_ecom_fee": "FRAIS ANNUELS DOTATIONS"
 }
+
+awb = {
+    "wire_in_same_bank": "VIR.WEB RECU DE",
+    "wire_in_conf": "VIREMENT RECU DE",
+    "wire_out": "VIR WEB VERS",
+    "withdrawal_gab": "AWBGAB",
+    "invoice_pay": "PAIEMENT ",
+    "card_pay": "PAIMENT/CB",
+    "ext_gab_fee": "FRAIS/RETRAIT ESP GAB",
+    "ecom_national": "",
+    "ecom_inter": "",
+    "card_pay": ""
+}
+
+banks = {
+    'CIH': cih,
+    'AWB': awb
+}
